@@ -25,15 +25,22 @@ class BuiltInProvider(ITestProvider):
     """
 
     _builtin_tests = [
+        'bootchart',
+        'insanity',
+        'firefox',
         'glmemperf',
         'gmpbench',
         'gtkperf',
         'ltp',
+        'peacekeeper',
         'posixtestsuite',
         'pwrmgmt',
+        'pybench',
+        'smem',
         'stream',
         'tiobench',
         'x11perf',
+        'xrestop',
     ]
 
     def __init__(self, config):
@@ -150,10 +157,13 @@ class RegistryProvider(ITestProvider):
             return
         self._cache = {}
         for test_url in self.entries:
-            test = self._load_remote_test(test_url)
-            if test.test_id in self._cache:
-                raise ValueError("Duplicate test %s declared" % test.test_id)
-            self._cache[test.test_id] = test
+            try:
+                test = self._load_remote_test(test_url)
+                if test.test_id in self._cache:
+                    raise ValueError("Duplicate test %s declared" % test.test_id)
+                self._cache[test.test_id] = test
+            except:
+                print("Warning: Failed to load test from '%s'" % test_url)
 
     def __iter__(self):
         self._fill_cache()
