@@ -18,14 +18,15 @@ from lava_test.core.parsers import TestParser
 from lava_test.core.runners import TestRunner
 from lava_test.core.tests import Test
 
+DEFAULT_OPTIONS = ""
 INSTALLSTEPS = ['bzr branch lp:~linaro-foundations/lava-test/bootchartscript']
 DEPS = ['bootchart', 'pybootchartgui', 'bzr']
-RUNSTEPS = ['./bootchartscript/bootchartscript.sh']
+RUNSTEPS = ['./bootchartscript/bootchartscript.sh $(OPTIONS)']
 PATTERN = "^(?P<test_case_id>\w+):\W+(?P<measurement>\d+\.\d+)"
 
 bootchartinst = TestInstaller(INSTALLSTEPS, deps=DEPS)
-bootchartrun = TestRunner(RUNSTEPS)
+bootchartrun = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
 bootchartparser = TestParser(PATTERN,
                    appendall={'units':'sec', 'result':'pass'})
-testobj = Test(testname="bootchart", installer=bootchartinst,
+testobj = Test(test_id="bootchart", installer=bootchartinst,
                                   runner=bootchartrun, parser=bootchartparser)
