@@ -19,14 +19,14 @@ from lava_test.core.parsers import TestParser
 from lava_test.core.runners import TestRunner
 from lava_test.core.tests import Test
 
-
+DEFAULT_OPTIONS = ""
 INSTALLSTEPS = ['git clone git://github.com/janimo/firefox-startup-timing.git']
 DEPS = ['firefox', 'git-core', 'gcalctool']
-RUNSTEPS = ['cd firefox-startup-timing; ./firefox_startup_timing.sh']
+RUNSTEPS = ['cd firefox-startup-timing; ./firefox_startup_timing.sh $(OPTIONS)']
 PATTERN = "^(?P<test_case_id>\w+):(?P<measurement>\d+)"
 
 firefoxinst = TestInstaller(INSTALLSTEPS, deps=DEPS)
-firefoxrun = TestRunner(RUNSTEPS)
+firefoxrun = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
 firefoxparser = TestParser(PATTERN,
                appendall={'units':'ms', 'result':'pass'})
 testobj = Test(test_id="firefox", installer=firefoxinst,
