@@ -51,8 +51,9 @@ FIXUPS = {"TBROK":"fail",
 
 
 class LTPParser(TestParser):
-    def parse(self):
-        filename = "testoutput.log"
+    def parse(self, artifacts):
+        filename = artifacts.stdout_pathname
+        print "filename=%s" %filename
         pat = re.compile(self.pattern)
         with open(filename, 'r') as fd:
             for line in fd.readlines():
@@ -65,12 +66,8 @@ class LTPParser(TestParser):
                     if subid == '0':
                         continue
                     results['test_case_id'] += "." + subid
-                    self.results['test_results'].append(results)
-        if self.fixupdict:
-            self.fixresults(self.fixupdict)
-        if self.appendall:
-            self.appendtoall(self.appendall)
-        self.fixids()
+                    self.results['test_results'].append(
+                        self.analyze_test_result(results))
 
 
 ltpinst = TestInstaller(INSTALLSTEPS, deps=DEPS, url=URL,
