@@ -21,11 +21,12 @@ from lava_test.core.tests import Test
 URL="http://www.cs.virginia.edu/stream/FTP/Code/stream.c"
 INSTALLSTEPS = ['cc stream.c -O2 -fopenmp -o stream']
 DEPS = ['gcc', 'build-essential']
-RUNSTEPS = ['./stream']
+DEFAULT_OPTIONS = ""
+RUNSTEPS = ['./stream $(OPTIONS)']
 PATTERN = "^(?P<test_case_id>\w+):\W+(?P<measurement>\d+\.\d+)"
 
 streaminst = TestInstaller(INSTALLSTEPS, deps=DEPS, url=URL)
-streamrun = TestRunner(RUNSTEPS)
+streamrun = TestRunner(RUNSTEPS,default_options=DEFAULT_OPTIONS)
 streamparser = TestParser(PATTERN,
                appendall={'units':'MB/s', 'result':'pass'})
 testobj = Test(test_id="stream", installer=streaminst,
